-
-
Notifications
You must be signed in to change notification settings - Fork 480
New issue
Have a question about this project? Sign up for a free GitHub account to open an issue and contact its maintainers and the community.
By clicking “Sign up for GitHub”, you agree to our terms of service and privacy statement. We’ll occasionally send you account related emails.
Already on GitHub? Sign in to your account
Immutable graphs must not be relabeled #15622
Comments
Branch: u/ncohen/15622 |
Branch pushed to git repo; I updated commit sha1. Last 10 new commits:
|
Commit: |
comment:4
The code looks good. Perhaps the error message should hint at how to create a mutable copy? |
comment:5
OKayyyyyyyy.. What about this ? Nathann |
Branch pushed to git repo; I updated commit sha1. New commits:
|
comment:7
Oops:
That is the only error, and I'll probably fix it in a review commit. |
comment:8
WTF?????? When I do the obvious and change
Where does the blankline come from? And why is there no blankline when doing the test interactively? |
comment:9
Ahaaa! You had a wrong class and a wrong error message in your test ("remove a vertex" versus "relabel"). |
comment:10
I don't get what the "obvious change from Nathann |
comment:11
Replying to @nathanncohen:
diff --git a/src/sage/graphs/base/static_sparse_backend.pyx b/src/sage/graphs/base/static_sparse_backend.pyx
index 9b5a8fe..e5b889e 100644
--- a/src/sage/graphs/base/static_sparse_backend.pyx
+++ b/src/sage/graphs/base/static_sparse_backend.pyx
@@ -417,12 +417,12 @@ class StaticSparseBackend(CGraphBackend):
TEST::
- sage: from sage.graphs.base.static_sparse_backend import StaticSparseCGraph
- sage: g = StaticSparseCGraph(graphs.PetersenGraph())
+ sage: from sage.graphs.base.static_sparse_backend import StaticSparseBackend
+ sage: g = StaticSparseBackend(graphs.PetersenGraph())
sage: g.relabel([],True)
Traceback (most recent call last):
...
- ValueError: Thou shalt not remove a vertex from an immutable graph
+ ValueError: Thou shalt not relabel an immutable graph
"""
raise ValueError("Thou shalt not relabel an immutable graph")
|
comment:12
For the record: It already takes 5 minutes to push my review commit. |
Changed branch from u/ncohen/15622 to u/SimonKing/ticket/15622 |
comment:14
Oh. Ahem. Right Sorryyyyyyyyyyyyyyyyyyyyyyyyyyy Nathann Review commit : I often Ctrl+C it before it ends. Trac sends the mails almost instantaneously, the trac ticket is updated at the same time. I just have no idea what it does afterwards. |
Changed branch from u/SimonKing/ticket/15622 to u/ncohen/15622 |
comment:15
It seems that once more I have to manually upload the commit. |
Changed branch from u/ncohen/15622 to u/SimonKing/ticket/15622 |
comment:16
I think it's because you should set the branch name before pushing the commit. Otherwise nothing is triggered on the trac server's side. Nathann |
comment:17
Okay. We are now in the Volker-Feared situation of a ticket which has a positive review, with a dependency which is still in Thanks for this commit ! Nathann |
comment:18
By the way, isn't the trac server 99999x times faster than yesterday ? Andrew said he would do something about it and it looks like he did Nathann |
Reviewer: Simon King |
comment:22
Various doctests fail (see also patchbot) |
comment:23
Gloops. Right. |
Changed branch from u/SimonKing/ticket/15622 to u/ncohen/15622 |
comment:24
That's the only way I found to make this work before #15623 is merged Nathann |
comment:25
Okay, it looks like the automatic message does not work, but the branch is updated ! Nathann |
comment:26
Replying to @vbraun:
WTF? When I reviewed it, things worked. Or did I accidentally merge other tickets that aren't dependencies for this? |
comment:27
Hooray. After pulling from the ticket branch and merging with the current develop branch,
Nathann's last commit looks like the right thing to do. Hence, I hope this time my positive review will persist... |
Now
Before, the following happened
This is actually another bug, as there should be a
vertex_ints
variable in static sparse graphs. But that's another problem to be addressed in another ticket:-P
Nathann
Depends on #15619
CC: @simon-king-jena
Component: graph theory
Author: Nathann Cohen
Branch/Commit: u/ncohen/15622 @
6398780
Reviewer: Simon King
Issue created by migration from https://trac.sagemath.org/ticket/15622
The text was updated successfully, but these errors were encountered: